from google.protobuf import (
    timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2,
)

# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: recording.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name="recording.proto",
    package="videoimu",
    syntax="proto3",
    serialized_options=b"\n\033se.lth.math.videoimucaptureB\017RecordingProtos",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n\x0frecording.proto\x12\x08videoimu\x1a\x1fgoogle/protobuf/timestamp.proto"\xba\x06\n\nCameraInfo\x12\x18\n\x10intrinsic_params\x18\x01 \x03(\x02\x12\x19\n\x11\x64istortion_params\x18\x02 \x03(\x02\x12#\n\x1boptical_image_stabilization\x18\x03 \x01(\x08\x12\x1b\n\x13video_stabilization\x18\x04 \x01(\x08\x12\x1d\n\x15\x64istortion_correction\x18\n \x01(\x08\x12\x1a\n\x12sensor_orientation\x18\x0e \x01(\x05\x12@\n\x11\x66ocus_calibration\x18\x05 \x01(\x0e\x32%.videoimu.CameraInfo.FocusCalibration\x12>\n\x10timestamp_source\x18\x06 \x01(\x0e\x32$.videoimu.CameraInfo.TimestampSource\x12\x43\n\x13lens_pose_reference\x18\x07 \x01(\x0e\x32&.videoimu.CameraInfo.LensPoseReference\x12\x1a\n\x12lens_pose_rotation\x18\x08 \x03(\x02\x12\x1d\n\x15lens_pose_translation\x18\t \x03(\x02\x12-\n\nresolution\x18\x0b \x01(\x0b\x32\x19.videoimu.CameraInfo.Size\x12\x43\n pre_correction_active_array_size\x18\x0c \x01(\x0b\x32\x19.videoimu.CameraInfo.Size\x12!\n\x19original_intrinsic_params\x18\r \x03(\x02\x1a%\n\x04Size\x12\r\n\x05width\x18\x01 \x01(\x05\x12\x0e\n\x06height\x18\x02 \x01(\x05"E\n\x10\x46ocusCalibration\x12\x10\n\x0cUNCALIBRATED\x10\x00\x12\x0f\n\x0b\x41PPROXIMATE\x10\x01\x12\x0e\n\nCALIBRATED\x10\x02",\n\x0fTimestampSource\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08REALTIME\x10\x01"E\n\x11LensPoseReference\x12\x12\n\x0ePRIMARY_CAMERA\x10\x00\x12\r\n\tGYROSCOPE\x10\x01\x12\r\n\tUNDEFINED\x10\x02";\n\x15VideoFrameToTimestamp\x12\x0f\n\x07time_us\x18\x01 \x01(\x03\x12\x11\n\tframe_nbr\x18\x02 \x01(\x03"\x82\x03\n\x12VideoFrameMetaData\x12\x0f\n\x07time_ns\x18\x01 \x01(\x03\x12\x14\n\x0c\x66rame_number\x18\x02 \x01(\x03\x12\x18\n\x10\x65xposure_time_ns\x18\x03 \x01(\x03\x12\x19\n\x11\x66rame_duration_ns\x18\x04 \x01(\x03\x12\x18\n\x10\x66rame_readout_ns\x18\x05 \x01(\x03\x12\x0b\n\x03iso\x18\x06 \x01(\x05\x12\x17\n\x0f\x66ocal_length_mm\x18\x07 \x01(\x02\x12\x1c\n\x14\x65st_focal_length_pix\x18\x08 \x01(\x02\x12\x1f\n\x17\x66ocus_distance_diopters\x18\t \x01(\x02\x12;\n\x0bOIS_samples\x18\n \x03(\x0b\x32&.videoimu.VideoFrameMetaData.OISSample\x12\x14\n\x0c\x66ocus_locked\x18\x0b \x01(\x08\x1a>\n\tOISSample\x12\x0f\n\x07time_ns\x18\x01 \x01(\x03\x12\x0f\n\x07x_shift\x18\x02 \x01(\x02\x12\x0f\n\x07y_shift\x18\x03 \x01(\x02"\x90\x01\n\x07IMUInfo\x12\x11\n\tgyro_info\x18\x01 \x01(\t\x12\x17\n\x0fgyro_resolution\x18\x02 \x01(\x02\x12\x12\n\naccel_info\x18\x03 \x01(\t\x12\x18\n\x10\x61\x63\x63\x65l_resolution\x18\x04 \x01(\x02\x12\x18\n\x10sample_frequency\x18\x05 \x01(\x02\x12\x11\n\tplacement\x18\x06 \x03(\x02"\x81\x02\n\x07IMUData\x12\x0f\n\x07time_ns\x18\x01 \x01(\x03\x12\x0c\n\x04gyro\x18\x02 \x03(\x02\x12\x12\n\ngyro_drift\x18\x03 \x03(\x02\x12\r\n\x05\x61\x63\x63\x65l\x18\x04 \x03(\x02\x12\x12\n\naccel_bias\x18\x05 \x03(\x02\x12\x31\n\rgyro_accuracy\x18\x06 \x01(\x0e\x32\x1a.videoimu.IMUData.Accuracy\x12\x32\n\x0e\x61\x63\x63\x65l_accuracy\x18\x07 \x01(\x0e\x32\x1a.videoimu.IMUData.Accuracy"9\n\x08\x41\x63\x63uracy\x12\x0e\n\nUNRELIABLE\x10\x00\x12\x07\n\x03LOW\x10\x01\x12\n\n\x06MEDIUM\x10\x02\x12\x08\n\x04HIGH\x10\x03"\xde\x01\n\x10VideoCaptureData\x12(\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12)\n\x0b\x63\x61mera_meta\x18\x02 \x01(\x0b\x32\x14.videoimu.CameraInfo\x12#\n\x08imu_meta\x18\x03 \x01(\x0b\x32\x11.videoimu.IMUInfo\x12\x1e\n\x03imu\x18\x04 \x03(\x0b\x32\x11.videoimu.IMUData\x12\x30\n\nvideo_meta\x18\x05 \x03(\x0b\x32\x1c.videoimu.VideoFrameMetaData"\xfd\x01\n\x0eMessageWrapper\x12+\n\x0b\x63\x61mera_meta\x18\x01 \x01(\x0b\x32\x14.videoimu.CameraInfoH\x00\x12%\n\x08imu_data\x18\x02 \x01(\x0b\x32\x11.videoimu.IMUDataH\x00\x12%\n\x08imu_meta\x18\x03 \x01(\x0b\x32\x11.videoimu.IMUInfoH\x00\x12\x32\n\nframe_meta\x18\x04 \x01(\x0b\x32\x1c.videoimu.VideoFrameMetaDataH\x00\x12\x35\n\nframe_time\x18\x05 \x01(\x0b\x32\x1f.videoimu.VideoFrameToTimestampH\x00\x42\x05\n\x03msgB.\n\x1bse.lth.math.videoimucaptureB\x0fRecordingProtosb\x06proto3',
    dependencies=[
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
    ],
)


_CAMERAINFO_FOCUSCALIBRATION = _descriptor.EnumDescriptor(
    name="FocusCalibration",
    full_name="videoimu.CameraInfo.FocusCalibration",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="UNCALIBRATED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="APPROXIMATE",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="CALIBRATED",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=703,
    serialized_end=772,
)
_sym_db.RegisterEnumDescriptor(_CAMERAINFO_FOCUSCALIBRATION)

_CAMERAINFO_TIMESTAMPSOURCE = _descriptor.EnumDescriptor(
    name="TimestampSource",
    full_name="videoimu.CameraInfo.TimestampSource",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="UNKNOWN",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="REALTIME",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=774,
    serialized_end=818,
)
_sym_db.RegisterEnumDescriptor(_CAMERAINFO_TIMESTAMPSOURCE)

_CAMERAINFO_LENSPOSEREFERENCE = _descriptor.EnumDescriptor(
    name="LensPoseReference",
    full_name="videoimu.CameraInfo.LensPoseReference",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="PRIMARY_CAMERA",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="GYROSCOPE",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="UNDEFINED",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=820,
    serialized_end=889,
)
_sym_db.RegisterEnumDescriptor(_CAMERAINFO_LENSPOSEREFERENCE)

_IMUDATA_ACCURACY = _descriptor.EnumDescriptor(
    name="Accuracy",
    full_name="videoimu.IMUData.Accuracy",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="UNRELIABLE",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="LOW",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="MEDIUM",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="HIGH",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=1689,
    serialized_end=1746,
)
_sym_db.RegisterEnumDescriptor(_IMUDATA_ACCURACY)


_CAMERAINFO_SIZE = _descriptor.Descriptor(
    name="Size",
    full_name="videoimu.CameraInfo.Size",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="width",
            full_name="videoimu.CameraInfo.Size.width",
            index=0,
            number=1,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="height",
            full_name="videoimu.CameraInfo.Size.height",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=664,
    serialized_end=701,
)

_CAMERAINFO = _descriptor.Descriptor(
    name="CameraInfo",
    full_name="videoimu.CameraInfo",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="intrinsic_params",
            full_name="videoimu.CameraInfo.intrinsic_params",
            index=0,
            number=1,
            type=2,
            cpp_type=6,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="distortion_params",
            full_name="videoimu.CameraInfo.distortion_params",
            index=1,
            number=2,
            type=2,
            cpp_type=6,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="optical_image_stabilization",
            full_name="videoimu.CameraInfo.optical_image_stabilization",
            index=2,
            number=3,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="video_stabilization",
            full_name="videoimu.CameraInfo.video_stabilization",
            index=3,
            number=4,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="distortion_correction",
            full_name="videoimu.CameraInfo.distortion_correction",
            index=4,
            number=10,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="sensor_orientation",
            full_name="videoimu.CameraInfo.sensor_orientation",
            index=5,
            number=14,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="focus_calibration",
            full_name="videoimu.CameraInfo.focus_calibration",
            index=6,
            number=5,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="timestamp_source",
            full_name="videoimu.CameraInfo.timestamp_source",
            index=7,
            number=6,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="lens_pose_reference",
            full_name="videoimu.CameraInfo.lens_pose_reference",
            index=8,
            number=7,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="lens_pose_rotation",
            full_name="videoimu.CameraInfo.lens_pose_rotation",
            index=9,
            number=8,
            type=2,
            cpp_type=6,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="lens_pose_translation",
            full_name="videoimu.CameraInfo.lens_pose_translation",
            index=10,
            number=9,
            type=2,
            cpp_type=6,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="resolution",
            full_name="videoimu.CameraInfo.resolution",
            index=11,
            number=11,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="pre_correction_active_array_size",
            full_name="videoimu.CameraInfo.pre_correction_active_array_size",
            index=12,
            number=12,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="original_intrinsic_params",
            full_name="videoimu.CameraInfo.original_intrinsic_params",
            index=13,
            number=13,
            type=2,
            cpp_type=6,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _CAMERAINFO_SIZE,
    ],
    enum_types=[
        _CAMERAINFO_FOCUSCALIBRATION,
        _CAMERAINFO_TIMESTAMPSOURCE,
        _CAMERAINFO_LENSPOSEREFERENCE,
    ],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=63,
    serialized_end=889,
)


_VIDEOFRAMETOTIMESTAMP = _descriptor.Descriptor(
    name="VideoFrameToTimestamp",
    full_name="videoimu.VideoFrameToTimestamp",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="time_us",
            full_name="videoimu.VideoFrameToTimestamp.time_us",
            index=0,
            number=1,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="frame_nbr",
            full_name="videoimu.VideoFrameToTimestamp.frame_nbr",
            index=1,
            number=2,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=891,
    serialized_end=950,
)


_VIDEOFRAMEMETADATA_OISSAMPLE = _descriptor.Descriptor(
    name="OISSample",
    full_name="videoimu.VideoFrameMetaData.OISSample",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="time_ns",
            full_name="videoimu.VideoFrameMetaData.OISSample.time_ns",
            index=0,
            number=1,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="x_shift",
            full_name="videoimu.VideoFrameMetaData.OISSample.x_shift",
            index=1,
            number=2,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="y_shift",
            full_name="videoimu.VideoFrameMetaData.OISSample.y_shift",
            index=2,
            number=3,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1277,
    serialized_end=1339,
)

_VIDEOFRAMEMETADATA = _descriptor.Descriptor(
    name="VideoFrameMetaData",
    full_name="videoimu.VideoFrameMetaData",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="time_ns",
            full_name="videoimu.VideoFrameMetaData.time_ns",
            index=0,
            number=1,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="frame_number",
            full_name="videoimu.VideoFrameMetaData.frame_number",
            index=1,
            number=2,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="exposure_time_ns",
            full_name="videoimu.VideoFrameMetaData.exposure_time_ns",
            index=2,
            number=3,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="frame_duration_ns",
            full_name="videoimu.VideoFrameMetaData.frame_duration_ns",
            index=3,
            number=4,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="frame_readout_ns",
            full_name="videoimu.VideoFrameMetaData.frame_readout_ns",
            index=4,
            number=5,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="iso",
            full_name="videoimu.VideoFrameMetaData.iso",
            index=5,
            number=6,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="focal_length_mm",
            full_name="videoimu.VideoFrameMetaData.focal_length_mm",
            index=6,
            number=7,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="est_focal_length_pix",
            full_name="videoimu.VideoFrameMetaData.est_focal_length_pix",
            index=7,
            number=8,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="focus_distance_diopters",
            full_name="videoimu.VideoFrameMetaData.focus_distance_diopters",
            index=8,
            number=9,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="OIS_samples",
            full_name="videoimu.VideoFrameMetaData.OIS_samples",
            index=9,
            number=10,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="focus_locked",
            full_name="videoimu.VideoFrameMetaData.focus_locked",
            index=10,
            number=11,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _VIDEOFRAMEMETADATA_OISSAMPLE,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=953,
    serialized_end=1339,
)


_IMUINFO = _descriptor.Descriptor(
    name="IMUInfo",
    full_name="videoimu.IMUInfo",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="gyro_info",
            full_name="videoimu.IMUInfo.gyro_info",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="gyro_resolution",
            full_name="videoimu.IMUInfo.gyro_resolution",
            index=1,
            number=2,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="accel_info",
            full_name="videoimu.IMUInfo.accel_info",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="accel_resolution",
            full_name="videoimu.IMUInfo.accel_resolution",
            index=3,
            number=4,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="sample_frequency",
            full_name="videoimu.IMUInfo.sample_frequency",
            index=4,
            number=5,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="placement",
            full_name="videoimu.IMUInfo.placement",
            index=5,
            number=6,
            type=2,
            cpp_type=6,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1342,
    serialized_end=1486,
)


_IMUDATA = _descriptor.Descriptor(
    name="IMUData",
    full_name="videoimu.IMUData",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="time_ns",
            full_name="videoimu.IMUData.time_ns",
            index=0,
            number=1,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="gyro",
            full_name="videoimu.IMUData.gyro",
            index=1,
            number=2,
            type=2,
            cpp_type=6,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="gyro_drift",
            full_name="videoimu.IMUData.gyro_drift",
            index=2,
            number=3,
            type=2,
            cpp_type=6,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="accel",
            full_name="videoimu.IMUData.accel",
            index=3,
            number=4,
            type=2,
            cpp_type=6,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="accel_bias",
            full_name="videoimu.IMUData.accel_bias",
            index=4,
            number=5,
            type=2,
            cpp_type=6,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="gyro_accuracy",
            full_name="videoimu.IMUData.gyro_accuracy",
            index=5,
            number=6,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="accel_accuracy",
            full_name="videoimu.IMUData.accel_accuracy",
            index=6,
            number=7,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[
        _IMUDATA_ACCURACY,
    ],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1489,
    serialized_end=1746,
)


_VIDEOCAPTUREDATA = _descriptor.Descriptor(
    name="VideoCaptureData",
    full_name="videoimu.VideoCaptureData",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="time",
            full_name="videoimu.VideoCaptureData.time",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="camera_meta",
            full_name="videoimu.VideoCaptureData.camera_meta",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="imu_meta",
            full_name="videoimu.VideoCaptureData.imu_meta",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="imu",
            full_name="videoimu.VideoCaptureData.imu",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="video_meta",
            full_name="videoimu.VideoCaptureData.video_meta",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1749,
    serialized_end=1971,
)


_MESSAGEWRAPPER = _descriptor.Descriptor(
    name="MessageWrapper",
    full_name="videoimu.MessageWrapper",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="camera_meta",
            full_name="videoimu.MessageWrapper.camera_meta",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="imu_data",
            full_name="videoimu.MessageWrapper.imu_data",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="imu_meta",
            full_name="videoimu.MessageWrapper.imu_meta",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="frame_meta",
            full_name="videoimu.MessageWrapper.frame_meta",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="frame_time",
            full_name="videoimu.MessageWrapper.frame_time",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="msg",
            full_name="videoimu.MessageWrapper.msg",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        ),
    ],
    serialized_start=1974,
    serialized_end=2227,
)

_CAMERAINFO_SIZE.containing_type = _CAMERAINFO
_CAMERAINFO.fields_by_name["focus_calibration"].enum_type = _CAMERAINFO_FOCUSCALIBRATION
_CAMERAINFO.fields_by_name["timestamp_source"].enum_type = _CAMERAINFO_TIMESTAMPSOURCE
_CAMERAINFO.fields_by_name[
    "lens_pose_reference"
].enum_type = _CAMERAINFO_LENSPOSEREFERENCE
_CAMERAINFO.fields_by_name["resolution"].message_type = _CAMERAINFO_SIZE
_CAMERAINFO.fields_by_name[
    "pre_correction_active_array_size"
].message_type = _CAMERAINFO_SIZE
_CAMERAINFO_FOCUSCALIBRATION.containing_type = _CAMERAINFO
_CAMERAINFO_TIMESTAMPSOURCE.containing_type = _CAMERAINFO
_CAMERAINFO_LENSPOSEREFERENCE.containing_type = _CAMERAINFO
_VIDEOFRAMEMETADATA_OISSAMPLE.containing_type = _VIDEOFRAMEMETADATA
_VIDEOFRAMEMETADATA.fields_by_name[
    "OIS_samples"
].message_type = _VIDEOFRAMEMETADATA_OISSAMPLE
_IMUDATA.fields_by_name["gyro_accuracy"].enum_type = _IMUDATA_ACCURACY
_IMUDATA.fields_by_name["accel_accuracy"].enum_type = _IMUDATA_ACCURACY
_IMUDATA_ACCURACY.containing_type = _IMUDATA
_VIDEOCAPTUREDATA.fields_by_name[
    "time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_VIDEOCAPTUREDATA.fields_by_name["camera_meta"].message_type = _CAMERAINFO
_VIDEOCAPTUREDATA.fields_by_name["imu_meta"].message_type = _IMUINFO
_VIDEOCAPTUREDATA.fields_by_name["imu"].message_type = _IMUDATA
_VIDEOCAPTUREDATA.fields_by_name["video_meta"].message_type = _VIDEOFRAMEMETADATA
_MESSAGEWRAPPER.fields_by_name["camera_meta"].message_type = _CAMERAINFO
_MESSAGEWRAPPER.fields_by_name["imu_data"].message_type = _IMUDATA
_MESSAGEWRAPPER.fields_by_name["imu_meta"].message_type = _IMUINFO
_MESSAGEWRAPPER.fields_by_name["frame_meta"].message_type = _VIDEOFRAMEMETADATA
_MESSAGEWRAPPER.fields_by_name["frame_time"].message_type = _VIDEOFRAMETOTIMESTAMP
_MESSAGEWRAPPER.oneofs_by_name["msg"].fields.append(
    _MESSAGEWRAPPER.fields_by_name["camera_meta"]
)
_MESSAGEWRAPPER.fields_by_name[
    "camera_meta"
].containing_oneof = _MESSAGEWRAPPER.oneofs_by_name["msg"]
_MESSAGEWRAPPER.oneofs_by_name["msg"].fields.append(
    _MESSAGEWRAPPER.fields_by_name["imu_data"]
)
_MESSAGEWRAPPER.fields_by_name[
    "imu_data"
].containing_oneof = _MESSAGEWRAPPER.oneofs_by_name["msg"]
_MESSAGEWRAPPER.oneofs_by_name["msg"].fields.append(
    _MESSAGEWRAPPER.fields_by_name["imu_meta"]
)
_MESSAGEWRAPPER.fields_by_name[
    "imu_meta"
].containing_oneof = _MESSAGEWRAPPER.oneofs_by_name["msg"]
_MESSAGEWRAPPER.oneofs_by_name["msg"].fields.append(
    _MESSAGEWRAPPER.fields_by_name["frame_meta"]
)
_MESSAGEWRAPPER.fields_by_name[
    "frame_meta"
].containing_oneof = _MESSAGEWRAPPER.oneofs_by_name["msg"]
_MESSAGEWRAPPER.oneofs_by_name["msg"].fields.append(
    _MESSAGEWRAPPER.fields_by_name["frame_time"]
)
_MESSAGEWRAPPER.fields_by_name[
    "frame_time"
].containing_oneof = _MESSAGEWRAPPER.oneofs_by_name["msg"]
DESCRIPTOR.message_types_by_name["CameraInfo"] = _CAMERAINFO
DESCRIPTOR.message_types_by_name["VideoFrameToTimestamp"] = _VIDEOFRAMETOTIMESTAMP
DESCRIPTOR.message_types_by_name["VideoFrameMetaData"] = _VIDEOFRAMEMETADATA
DESCRIPTOR.message_types_by_name["IMUInfo"] = _IMUINFO
DESCRIPTOR.message_types_by_name["IMUData"] = _IMUDATA
DESCRIPTOR.message_types_by_name["VideoCaptureData"] = _VIDEOCAPTUREDATA
DESCRIPTOR.message_types_by_name["MessageWrapper"] = _MESSAGEWRAPPER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CameraInfo = _reflection.GeneratedProtocolMessageType(
    "CameraInfo",
    (_message.Message,),
    {
        "Size": _reflection.GeneratedProtocolMessageType(
            "Size",
            (_message.Message,),
            {
                "DESCRIPTOR": _CAMERAINFO_SIZE,
                "__module__": "recording_pb2"
                # @@protoc_insertion_point(class_scope:videoimu.CameraInfo.Size)
            },
        ),
        "DESCRIPTOR": _CAMERAINFO,
        "__module__": "recording_pb2"
        # @@protoc_insertion_point(class_scope:videoimu.CameraInfo)
    },
)
_sym_db.RegisterMessage(CameraInfo)
_sym_db.RegisterMessage(CameraInfo.Size)

VideoFrameToTimestamp = _reflection.GeneratedProtocolMessageType(
    "VideoFrameToTimestamp",
    (_message.Message,),
    {
        "DESCRIPTOR": _VIDEOFRAMETOTIMESTAMP,
        "__module__": "recording_pb2"
        # @@protoc_insertion_point(class_scope:videoimu.VideoFrameToTimestamp)
    },
)
_sym_db.RegisterMessage(VideoFrameToTimestamp)

VideoFrameMetaData = _reflection.GeneratedProtocolMessageType(
    "VideoFrameMetaData",
    (_message.Message,),
    {
        "OISSample": _reflection.GeneratedProtocolMessageType(
            "OISSample",
            (_message.Message,),
            {
                "DESCRIPTOR": _VIDEOFRAMEMETADATA_OISSAMPLE,
                "__module__": "recording_pb2"
                # @@protoc_insertion_point(class_scope:videoimu.VideoFrameMetaData.OISSample)
            },
        ),
        "DESCRIPTOR": _VIDEOFRAMEMETADATA,
        "__module__": "recording_pb2"
        # @@protoc_insertion_point(class_scope:videoimu.VideoFrameMetaData)
    },
)
_sym_db.RegisterMessage(VideoFrameMetaData)
_sym_db.RegisterMessage(VideoFrameMetaData.OISSample)

IMUInfo = _reflection.GeneratedProtocolMessageType(
    "IMUInfo",
    (_message.Message,),
    {
        "DESCRIPTOR": _IMUINFO,
        "__module__": "recording_pb2"
        # @@protoc_insertion_point(class_scope:videoimu.IMUInfo)
    },
)
_sym_db.RegisterMessage(IMUInfo)

IMUData = _reflection.GeneratedProtocolMessageType(
    "IMUData",
    (_message.Message,),
    {
        "DESCRIPTOR": _IMUDATA,
        "__module__": "recording_pb2"
        # @@protoc_insertion_point(class_scope:videoimu.IMUData)
    },
)
_sym_db.RegisterMessage(IMUData)

VideoCaptureData = _reflection.GeneratedProtocolMessageType(
    "VideoCaptureData",
    (_message.Message,),
    {
        "DESCRIPTOR": _VIDEOCAPTUREDATA,
        "__module__": "recording_pb2"
        # @@protoc_insertion_point(class_scope:videoimu.VideoCaptureData)
    },
)
_sym_db.RegisterMessage(VideoCaptureData)

MessageWrapper = _reflection.GeneratedProtocolMessageType(
    "MessageWrapper",
    (_message.Message,),
    {
        "DESCRIPTOR": _MESSAGEWRAPPER,
        "__module__": "recording_pb2"
        # @@protoc_insertion_point(class_scope:videoimu.MessageWrapper)
    },
)
_sym_db.RegisterMessage(MessageWrapper)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
