joint_definition = [
    ["HEAD", "NECK"],
    ["NECK", "SPINE_CHEST"],
    ["SPINE_CHEST", "SPINE_NAVEL"],
    ["SPINE_NAVEL", "PELVIS"],
    ["PELVIS", "HIP_RIGHT"],
    ["HIP_RIGHT", "KNEE_RIGHT"],
    ["KNEE_RIGHT", "ANKLE_RIGHT"],
    ["ANKLE_RIGHT", "FOOT_RIGHT"],
    ["PELVIS", "HIP_LEFT"],
    ["HIP_LEFT", "KNEE_LEFT"],
    ["KNEE_LEFT", "ANKLE_LEFT"],
    ["ANKLE_LEFT", "FOOT_LEFT"],
    ["SPINE_CHEST", "CLAVICLE_LEFT"],
    ["CLAVICLE_LEFT", "SHOULDER_LEFT"],
    ["SHOULDER_LEFT", "ELBOW_LEFT"],
    ["ELBOW_LEFT", "WRIST_LEFT"],
    ["WRIST_LEFT", "HAND_LEFT"],
    ["HAND_LEFT", "HANDTIP_LEFT"],
    ["WRIST_LEFT", "THUMB_LEFT"],
    ["SPINE_CHEST", "CLAVICLE_RIGHT"],
    ["CLAVICLE_RIGHT", "SHOULDER_RIGHT"],
    ["SHOULDER_RIGHT", "ELBOW_RIGHT"],
    ["ELBOW_RIGHT", "WRIST_RIGHT"],
    ["WRIST_RIGHT", "HAND_RIGHT"],
    ["HAND_RIGHT", "HANDTIP_RIGHT"],
    ["WRIST_RIGHT", "THUMB_RIGHT"],
]
